// ============================================================================
//
// Copyright (C) 2006-2012 Talend Inc. - www.talend.com
//
// This source code is available under agreement available at
// %InstallDIR%\features\org.talend.rcp.branding.%PRODUCTNAME%\%PRODUCTNAME%license.txt
//
// You should have received a copy of the agreement
// along with this program; if not, write to Talend SA
// 9 rue Pages 92150 Suresnes, France
//
// ============================================================================
package org.talend.oracle;

import oracle.sql.ZONEIDMAP;

/**
 * created by bchen on Oct 15, 2012 Detailled comment
 * 
 */
public class OracleTSTZ {

    private int year;

    private int month;

    private int day;

    private int hour;

    private int min;

    private int second;

    private int nano;

    private String zone;

    private static int TS_SIZE = 11;

    private static byte REGIONIDBIT = -128;

    public OracleTSTZ(byte[] oracleTSTZs) {
        init(oracleTSTZs);
    }

    private void init(byte[] oracleTSTZbs) {
        int[] oracleTSTZis = new int[TS_SIZE];
        for (int i = 0; i < TS_SIZE; i++) {
            oracleTSTZis[i] = oracleTSTZbs[i] & 0xFF;
        }
        year = (oracleTSTZis[0] - 100) * 100 + (oracleTSTZis[1] - 100);
        month = oracleTSTZis[2];
        day = oracleTSTZis[3];
        hour = oracleTSTZis[4];
        min = oracleTSTZis[5];
        second = oracleTSTZis[6];
        int tempNano = oracleTSTZis[7] << 24;
        tempNano |= oracleTSTZis[8] << 16;
        tempNano |= oracleTSTZis[9] << 8;
        tempNano |= oracleTSTZis[10];
        nano = tempNano;

        if ((oracleTSTZbs[11] & REGIONIDBIT) != 0) {
            int id = (oracleTSTZbs[11] & 127) << 6;
            id += ((oracleTSTZbs[12] & 252) >> 2);
            zone = new String(ZONEIDMAP.getRegion(id));
        } else {
            int zoneH = oracleTSTZbs[11] - 20;
            String sign = zoneH > 0 ? "+" : "-";
            zoneH = Math.abs(zoneH);
            int zoneM = Math.abs(oracleTSTZbs[12] - 60);
            String zoneMs = zoneM < 10 ? "0" + zoneM : zoneM + "";
            zone = "GMT" + sign + zoneH + ":" + zoneMs;
        }
    }

    /**
     * Getter for year.
     * 
     * @return the year
     */
    public int getYear() {
        return this.year;
    }

    /**
     * Getter for month.
     * 
     * @return the month
     */
    public int getMonth() {
        return this.month;
    }

    /**
     * Getter for day.
     * 
     * @return the day
     */
    public int getDay() {
        return this.day;
    }

    /**
     * Getter for hour.
     * 
     * @return the hour
     */
    public int getHour() {
        return this.hour;
    }

    /**
     * Getter for min.
     * 
     * @return the min
     */
    public int getMin() {
        return this.min;
    }

    /**
     * Getter for second.
     * 
     * @return the second
     */
    public int getSecond() {
        return this.second;
    }

    /**
     * Getter for nano.
     * 
     * @return the nano
     */
    public int getNano() {
        return this.nano;
    }

    /**
     * Getter for zone.
     * 
     * @return the zone
     */
    public String getZone() {
        return this.zone;
    }

    /**
     * Getter for tS_SIZE.
     * 
     * @return the tS_SIZE
     */
    public static int getTS_SIZE() {
        return TS_SIZE;
    }

    /**
     * Getter for rEGIONIDBIT.
     * 
     * @return the rEGIONIDBIT
     */
    public static byte getREGIONIDBIT() {
        return REGIONIDBIT;
    }
}
